Blob Blame History Raw
commit c58d9d6e26a323e1525fb5683a0e3fbe1eee9c22
Author: Orion Poplawski <orion@cora.nwra.com>
Date:   Fri Sep 30 15:49:39 2016 -0600

    Fix spelling of rhomboid

diff --git a/examples/draw-proto.py b/examples/draw-proto.py
index 3db1b99..4edc361 100755
--- a/examples/draw-proto.py
+++ b/examples/draw-proto.py
@@ -107,7 +107,7 @@ class Window(object):
                 current.motion(e)
 
 # A drawed objects, consisting of either a single
 # romboid, or two romboids connected by a winding line
 
 class Movement(object):
     def __init__(self, win, ev):
@@ -121,7 +121,7 @@ class Movement(object):
         self.time = ev.time
         self.lines = [(ev.event_x, ev.event_y)]
 
-        self.first = Romboid(self.win, ev)
+        self.first = Rhomboid(self.win, ev)
         self.last = None
 
     def motion(self, ev):
@@ -182,7 +182,7 @@ class Movement(object):
     def finish(self, ev):
         self.motion(ev)
         if len(self.lines) > 1:
-            self.last = Romboid(self.win, ev)
+            self.last = Rhomboid(self.win, ev)
 
             self.left = min(ev.event_x - 5, self.left)
             self.right = max(ev.event_x + 5, self.right)
@@ -206,8 +206,8 @@ class Movement(object):
                 self.last.draw()
 
 
-# A romboid, drawed around the Movement endpoints
-class Romboid(object):
+# A rhomboid, drawed around the Movement endpoints
+class Rhomboid(object):
     def __init__(self, win, ev):
         self.win = win
         self.x = ev.event_x
@@ -215,7 +215,7 @@ class Romboid(object):
         self.draw()
 
     def draw(self):
         # Draw the segments of the romboid
         PolyLine(self.win.d, None,
                  X.CoordModePrevious,
                  self.win.window,
@@ -107,7 +107,7 @@ class Window(object):
 
 # A drawed objects, consisting of either a single
-# romboid, or two romboids connected by a winding line
+# rhomboid, or two rhomboids connected by a winding line
 
 class Movement(object):
@@ -215,7 +215,7 @@ class Romboid(object):
 
     def draw(self):
-        # Draw the segments of the romboid
+        # Draw the segments of the rhomboid
         PolyLine(self.win.d, None,
                  X.CoordModePrevious,
diff --git a/examples/draw.py b/examples/draw.py
index 8832a50..f456d80 100755
--- a/examples/draw.py
+++ b/examples/draw.py
@@ -118,7 +118,7 @@ class Window(object):
                         sys.exit(0)
 
 # A drawed objects, consisting of either a single
 # romboid, or two romboids connected by a winding line
 
 class Movement(object):
     def __init__(self, win, ev):
@@ -132,7 +132,7 @@ class Movement(object):
         self.time = ev.time
         self.lines = [(ev.event_x, ev.event_y)]
 
-        self.first = Romboid(self.win, ev)
+        self.first = Rhomboid(self.win, ev)
         self.last = None
 
     def motion(self, ev):
@@ -185,7 +185,7 @@ class Movement(object):
     def finish(self, ev):
         self.motion(ev)
         if len(self.lines) > 1:
-            self.last = Romboid(self.win, ev)
+            self.last = Rhomboid(self.win, ev)
 
             self.left = min(ev.event_x - 5, self.left)
             self.right = max(ev.event_x + 5, self.right)
@@ -207,8 +207,8 @@ class Movement(object):
                 self.last.draw()
 
 
-# A romboid, drawed around the Movement endpoints
-class Romboid(object):
+# A rhomboid, drawed around the Movement endpoints
+class Rhomboid(object):
     def __init__(self, win, ev):
         self.win = win
         self.x = ev.event_x
@@ -216,7 +216,7 @@ class Romboid(object):
         self.draw()
 
     def draw(self):
         # Draw the segments of the romboid
         self.win.window.poly_line(self.win.gc, X.CoordModePrevious,
                                   [(self.x, self.y - 5),
                                    (5, 5),
@@ -118,7 +118,7 @@ class Window(object):
 
 # A drawed objects, consisting of either a single
-# romboid, or two romboids connected by a winding line
+# rhomboid, or two rhomboids connected by a winding line
 
 class Movement(object):
@@ -216,7 +216,7 @@ class Romboid(object):
 
     def draw(self):
-        # Draw the segments of the romboid
+        # Draw the segments of the rhomboid
         self.win.window.poly_line(self.win.gc, X.CoordModePrevious,
                                   [(self.x, self.y - 5),